[Mailman-Developers] patch: reply-to list and sender

Christian Seitz chris@in-berlin.de
Sun, 21 Jul 2002 16:24:46 +0200 (CEST)


Hi all,

we moved our mailing lists from Majordomo to Mailman several months ago
and one disadvantage of Mailman is, that you can set the reply-to only to
"Poster", "This list" and "Explicit address", but not to something like
"This list and sender".

This patch is testet with Mailman 2.0.6 to 2.0.11 and it works fine for
us. Could you please include this patch in the next version of Mailman?

--- mailman-2.0.11/Mailman/MailList.py	Sun Jul 21 15:51:06 2002
+++ mailman-2.0.11-patched/Mailman/MailList.py	Sun Jul 21 15:51:10 2002
@@ -420,7 +420,7 @@
 	     ' text will be added to the unsubscribe message.'),

 	    ('reply_goes_to_list', mm_cfg.Radio,
-             ('Poster', 'This list', 'Explicit address'), 0,
+             ('Poster', 'This list', 'Explicit address', 'This list and sender'), 0,
              '''Where are replies to list messages directed?  <tt>Poster</tt>
 is <em>strongly</em> recommended for most mailing lists.''',

--- mailman-2.0.11/Mailman/Handlers/CookHeaders.py	Sun Jul 21 15:51:44 2002
+++ mailman-2.0.11-patched/Mailman/Handlers/CookHeaders.py	Sun Jul 21 15:51:41 2002
@@ -89,7 +89,11 @@
         elif mlist.reply_goes_to_list == 2:
             xreplyto = msg.get('reply-to')
             msg['Reply-To'] = mlist.reply_to_address
-        # Give the recipient some ability to un-munge things.
+        # Set Reply-To: to list and sender
+        elif mlist.reply_goes_to_list == 3:
+           xreplyto = msg.get('reply-to')
+           msg['Reply-To'] = mlist.GetListEmail() + ', ' + msg.GetSender()
+        # Give the recipient some ability to un-munge things.
         if xreplyto:
             msg['X-Reply-To'] = xreplyto
     #

Chris
-- 
Christian Seitz <chris@in-berlin.de>            http://berli.net/
IN-Berlin - http://www.in-berlin.de/

PGP Fingerprint: A9 17 03 0D 36 AB 07 4E  D0 1E C3 8E 3F B0 66 9A